@@ -77,13 +77,15 @@ class NodegroupStates(Enum):
 
 class EksHook(AwsBaseHook):
     """
-    Interact with Amazon EKS, using the boto3 library.
+    Interact with Amazon Elastic Kubernetes Service (EKS).
+
+    Provide thin wrapper around :external+boto3:py:class:`boto3.client("eks") <EKS.Client>`.
 
     Additional arguments (such as ``aws_conn_id``) may be specified and
     are passed down to the underlying AwsBaseHook.
 
     .. seealso::
-        :class:`~airflow.providers.amazon.aws.hooks.base_aws.AwsBaseHook`
+        - :class:`airflow.providers.amazon.aws.hooks.base_aws.AwsBaseHook`
     """
 
     client_type = "eks"
@@ -102,6 +104,9 @@ class EksHook(AwsBaseHook):
         """
         Creates an Amazon EKS control plane.
 
+        .. seealso::
+            - :external+boto3:py:meth:`EKS.Client.create_cluster`
+
         :param name: The unique name to give to your Amazon EKS Cluster.
         :param roleArn: The Amazon Resource Name (ARN) of the IAM role that provides permissions
           for the Kubernetes control plane to make calls to AWS API operations on your behalf.
@@ -131,6 +136,9 @@ class EksHook(AwsBaseHook):
         """
         Creates an Amazon EKS managed node group for an Amazon EKS Cluster.
 
+        .. seealso::
+            - :external+boto3:py:meth:`EKS.Client.create_nodegroup`
+
         :param clusterName: The name of the Amazon EKS cluster to create the EKS Managed Nodegroup in.
         :param nodegroupName: The unique name to give your managed nodegroup.
         :param subnets: The subnets to use for the Auto Scaling group that is created for your nodegroup.
@@ -176,6 +184,9 @@ class EksHook(AwsBaseHook):
         """
         Creates an AWS Fargate profile for an Amazon EKS cluster.
 
+        .. seealso::
+            - :external+boto3:py:meth:`EKS.Client.create_fargate_profile`
+
         :param clusterName: The name of the Amazon EKS cluster to apply the Fargate profile to.
         :param fargateProfileName: The name of the Fargate profile.
         :param podExecutionRoleArn: The Amazon Resource Name (ARN) of the pod execution role to
@@ -205,6 +216,9 @@ class EksHook(AwsBaseHook):
         """
         Deletes the Amazon EKS Cluster control plane.
 
+        .. seealso::
+            - :external+boto3:py:meth:`EKS.Client.delete_cluster`
+
         :param name: The name of the cluster to delete.
 
         :return: Returns descriptive information about the deleted EKS Cluster.
@@ -220,6 +234,9 @@ class EksHook(AwsBaseHook):
         """
         Deletes an Amazon EKS managed node group from a specified cluster.
 
+        .. seealso::
+            - :external+boto3:py:meth:`EKS.Client.delete_nodegroup`
+
         :param clusterName: The name of the Amazon EKS Cluster that is associated with your nodegroup.
         :param nodegroupName: The name of the nodegroup to delete.
 
@@ -240,6 +257,9 @@ class EksHook(AwsBaseHook):
         """
         Deletes an AWS Fargate profile from a specified Amazon EKS cluster.
 
+        .. seealso::
+            - :external+boto3:py:meth:`EKS.Client.delete_fargate_profile`
+
         :param clusterName: The name of the Amazon EKS cluster associated with the Fargate profile to delete.
         :param fargateProfileName: The name of the Fargate profile to delete.
 
@@ -262,6 +282,9 @@ class EksHook(AwsBaseHook):
         """
         Returns descriptive information about an Amazon EKS Cluster.
 
+        .. seealso::
+            - :external+boto3:py:meth:`EKS.Client.describe_cluster`
+
         :param name: The name of the cluster to describe.
         :param verbose: Provides additional logging if set to True.  Defaults to False.
 
@@ -283,6 +306,9 @@ class EksHook(AwsBaseHook):
         """
         Returns descriptive information about an Amazon EKS managed node group.
 
+        .. seealso::
+            - :external+boto3:py:meth:`EKS.Client.describe_nodegroup`
+
         :param clusterName: The name of the Amazon EKS Cluster associated with the nodegroup.
         :param nodegroupName: The name of the nodegroup to describe.
         :param verbose: Provides additional logging if set to True.  Defaults to False.
@@ -312,6 +338,9 @@ class EksHook(AwsBaseHook):
         """
         Returns descriptive information about an AWS Fargate profile.
 
+        .. seealso::
+            - :external+boto3:py:meth:`EKS.Client.describe_fargate_profile`
+
         :param clusterName: The name of the Amazon EKS Cluster associated with the Fargate profile.
         :param fargateProfileName: The name of the Fargate profile to describe.
         :param verbose: Provides additional logging if set to True.  Defaults to False.
@@ -340,6 +369,9 @@ class EksHook(AwsBaseHook):
         """
         Returns the current status of a given Amazon EKS Cluster.
 
+        .. seealso::
+            - :external+boto3:py:meth:`EKS.Client.describe_cluster`
+
         :param clusterName: The name of the cluster to check.
 
         :return: Returns the current status of a given Amazon EKS Cluster.
@@ -357,6 +389,9 @@ class EksHook(AwsBaseHook):
         """
         Returns the current status of a given AWS Fargate profile.
 
+        .. seealso::
+            - :external+boto3:py:meth:`EKS.Client.describe_fargate_profile`
+
         :param clusterName: The name of the Amazon EKS Cluster associated with the Fargate profile.
         :param fargateProfileName: The name of the Fargate profile to check.
 
@@ -381,6 +416,9 @@ class EksHook(AwsBaseHook):
         """
         Returns the current status of a given Amazon EKS managed node group.
 
+        .. seealso::
+            - :external+boto3:py:meth:`EKS.Client.describe_nodegroup`
+
         :param clusterName: The name of the Amazon EKS Cluster associated with the nodegroup.
         :param nodegroupName: The name of the nodegroup to check.
 
@@ -406,6 +444,9 @@ class EksHook(AwsBaseHook):
         """
         Lists all Amazon EKS Clusters in your AWS account.
 
+        .. seealso::
+            - :external+boto3:py:meth:`EKS.Client.list_clusters`
+
         :param verbose: Provides additional logging if set to True.  Defaults to False.
 
         :return: A List containing the cluster names.
@@ -423,6 +464,9 @@ class EksHook(AwsBaseHook):
         """
         Lists all Amazon EKS managed node groups associated with the specified cluster.
 
+        .. seealso::
+            - :external+boto3:py:meth:`EKS.Client.list_nodegroups`
+
         :param clusterName: The name of the Amazon EKS Cluster containing nodegroups to list.
         :param verbose: Provides additional logging if set to True.  Defaults to False.
 
@@ -441,6 +485,9 @@ class EksHook(AwsBaseHook):
         """
         Lists all AWS Fargate profiles associated with the specified cluster.
 
+        .. seealso::
+            - :external+boto3:py:meth:`EKS.Client.list_fargate_profiles`
+
         :param clusterName: The name of the Amazon EKS Cluster containing Fargate profiles to list.
         :param verbose: Provides additional logging if set to True.  Defaults to False.
 
